@@ -39,21 +39,30 @@ class Token(base.AuthMethodHandler):
         return token_model.KeystoneToken(token_id=token_id,
                                          token_data=response)
 
-    def authenticate(self, request, auth_payload, user_context):
+    def authenticate(self, request, auth_payload):
         if 'id' not in auth_payload:
             raise exception.ValidationError(attribute='id',
                                             target='token')
         token_ref = self._get_token_ref(auth_payload)
         if token_ref.is_federated_user and self.federation_api:
-            mapped.handle_scoped_token(
-                request, auth_payload, user_context, token_ref,
-                self.federation_api, self.identity_api,
-                self.token_provider_api)
+            response_data = mapped.handle_scoped_token(
+                request, token_ref, self.federation_api, self.identity_api)
         else:
-            token_authenticate(request, auth_payload, user_context, token_ref)
+            response_data = token_authenticate(request,
+                                               token_ref)
+
+        # NOTE(notmorgan): The Token auth method is *very* special and sets the
+        # previous values to the method_names. This is because it can be used
+        # for re-scoping and we want to maintain the values. Most
+        # AuthMethodHandlers do no such thing and this is not required.
+        response_data.setdefault('method_names', []).extend(token_ref.methods)
+
+        return base.AuthHandlerResponse(status=True, response_body=None,
+                                        response_data=response_data)
 
 
-def token_authenticate(request, auth_payload, user_context, token_ref):
+def token_authenticate(request, token_ref):
+    response_data = {}
     try:
 
         # Do not allow tokens used for delegation to
@@ -61,13 +70,22 @@ def token_authenticate(request, auth_payload, user_context, token_ref):
         # state in Keystone. To do so is to invite elevation of
         # privilege attacks
 
-        if token_ref.oauth_scoped or token_ref.trust_scoped:
-            raise exception.Forbidden()
+        if token_ref.oauth_scoped:
+            raise exception.ForbiddenAction(
+                action=_(
+                    'Using OAuth-scoped token to create another token. '
+                    'Create a new OAuth-scoped token instead'))
+        elif token_ref.trust_scoped:
+            raise exception.ForbiddenAction(
+                action=_(
+                    'Using trust-scoped token to create another token. '
+                    'Create a new trust-scoped token instead'))
 
         if not CONF.token.allow_rescope_scoped_token:
             # Do not allow conversion from scoped tokens.
             if token_ref.project_scoped or token_ref.domain_scoped:
-                raise exception.Forbidden(action=_("rescope a scoped token"))
+                raise exception.ForbiddenAction(
+                    action=_('rescope a scoped token'))
 
         wsgi.validate_token_bind(request.context_dict, token_ref)
 
@@ -84,13 +102,19 @@ def token_authenticate(request, auth_payload, user_context, token_ref):
             # issued prior to audit id existing, the chain is not tracked.
             token_audit_id = None
 
-        user_context.setdefault('expires_at', token_ref.expires)
-        user_context['audit_id'] = token_audit_id
-        user_context.setdefault('user_id', token_ref.user_id)
+        # To prevent users from never having to re-authenticate, the original
+        # token expiration time is maintained in the new token. Not doing this
+        # would make it possible for a user to continuously bump token
+        # expiration through token rescoping without proving their identity.
+        response_data.setdefault('expires_at', token_ref.expires)
+        response_data['audit_id'] = token_audit_id
+        response_data.setdefault('user_id', token_ref.user_id)
         # TODO(morganfainberg: determine if token 'extras' can be removed
-        # from the user_context
-        user_context['extras'].update(token_ref.get('extras', {}))
-        user_context['method_names'].extend(token_ref.methods)
+        # from the response_data
+        response_data.setdefault('extras', {}).update(
+            token_ref.get('extras', {}))
+
+        return response_data
 
     except AssertionError as e:
         LOG.error(six.text_type(e))
