@@ -23,7 +23,6 @@ import migrate
 from oslo_config import cfg
 from oslo_db.sqlalchemy import migration
 from oslo_log import log
-from oslo_log import versionutils
 from oslo_serialization import jsonutils
 import pbr.version
 
@@ -1100,11 +1099,6 @@ class DomainConfigUpload(BaseApp):
 
     @staticmethod
     def main():
-        versionutils.report_deprecated_feature(
-            LOG,
-            "keystone-manage domain_config_upload is deprecated as of "
-            "Newton in favor of setting domain config options via the API "
-            "and may be removed in 'P' release.")
         dcu = DomainConfigUploadFiles()
         status = dcu.run()
         if status is not None:
