@@ -18,7 +18,6 @@
 
 """Utility methods for working with WSGI servers."""
 
-import copy
 import functools
 import itertools
 import re
@@ -35,13 +34,14 @@ from six.moves import http_client
 import webob.dec
 import webob.exc
 
+from keystone.common import authorization
 from keystone.common import dependency
 from keystone.common import json_home
 from keystone.common import request as request_mod
 from keystone.common import utils
 import keystone.conf
 from keystone import exception
-from keystone.i18n import _, _LI, _LW
+from keystone.i18n import _
 from keystone.models import token_model
 
 
@@ -104,7 +104,7 @@ def validate_token_bind(context, token_ref):
                 LOG.info(msg)
                 raise exception.Unauthorized(msg)
 
-            LOG.info(_LI('Kerberos bind authentication successful'))
+            LOG.info('Kerberos bind authentication successful')
 
         elif bind_mode == 'permissive':
             LOG.debug(("Ignoring unknown bind (due to permissive mode): "
@@ -228,8 +228,8 @@ class Application(BaseApplication):
             result = method(req, **params)
         except exception.Unauthorized as e:
             LOG.warning(
-                _LW("Authorization failed. %(exception)s from "
-                    "%(remote_addr)s"),
+                "Authorization failed. %(exception)s from "
+                "%(remote_addr)s",
                 {'exception': e, 'remote_addr': req.environ['REMOTE_ADDR']})
             return render_exception(e,
                                     context=req.context_dict,
@@ -291,28 +291,7 @@ class Application(BaseApplication):
             does not have the admin role
 
         """
-        request.assert_authenticated()
-
-        if not request.context.is_admin:
-            user_token_ref = utils.get_token_ref(request.context_dict)
-
-            creds = copy.deepcopy(user_token_ref.metadata)
-
-            try:
-                creds['user_id'] = user_token_ref.user_id
-            except exception.UnexpectedError:
-                LOG.debug('Invalid user')
-                raise exception.Unauthorized(_('Invalid user'))
-
-            if user_token_ref.project_scoped:
-                creds['tenant_id'] = user_token_ref.project_id
-            else:
-                LOG.debug('Invalid tenant')
-                raise exception.Unauthorized(_('Invalid tenant'))
-
-            creds['roles'] = user_token_ref.role_names
-            # Accept either is_admin or the admin role
-            self.policy_api.enforce(creds, 'admin_required', {})
+        authorization.assert_admin(self, request)
 
     def _attribute_is_empty(self, ref, attribute):
         """Determine if the attribute in ref is empty or None."""
@@ -527,7 +506,8 @@ class Router(object):
         """
         match = req.environ['wsgiorg.routing_args'][1]
         if not match:
-            msg = _('The resource could not be found.')
+            msg = (_('(%(url)s): The resource could not be found.') %
+                   {'url': req.url})
             return render_exception(exception.NotFound(msg),
                                     request=req,
                                     user_locale=best_match_language(req))
@@ -765,7 +745,8 @@ def render_response(body=None, status=None, headers=None, method=None):
 
     resp = webob.Response(body=body,
                           status='%d %s' % status,
-                          headerlist=headers)
+                          headerlist=headers,
+                          charset='utf-8')
 
     if method and method.upper() == 'HEAD':
         # NOTE(morganfainberg): HEAD requests should return the same status
