@@ -14,12 +14,12 @@
 
 import datetime
 
-from oslo_log import versionutils
 import sqlalchemy
 from sqlalchemy.ext.hybrid import hybrid_property
 from sqlalchemy import orm
 from sqlalchemy.orm import collections
 
+from keystone.common import password_hashing
 from keystone.common import resource_options
 from keystone.common import sql
 import keystone.conf
@@ -29,17 +29,17 @@ from keystone.identity.backends import resource_options as iro
 CONF = keystone.conf.CONF
 
 
-class User(sql.ModelBase, sql.DictBase):
+class User(sql.ModelBase, sql.ModelDictMixinWithExtras):
     __tablename__ = 'user'
     attributes = ['id', 'name', 'domain_id', 'password', 'enabled',
                   'default_project_id', 'password_expires_at']
-    readonly_attributes = ['id', 'password_expires_at']
+    readonly_attributes = ['id', 'password_expires_at', 'password']
     resource_options_registry = iro.USER_OPTIONS_REGISTRY
     id = sql.Column(sql.String(64), primary_key=True)
     domain_id = sql.Column(sql.String(64), nullable=False)
     _enabled = sql.Column('enabled', sql.Boolean)
     extra = sql.Column(sql.JsonBlob())
-    default_project_id = sql.Column(sql.String(64))
+    default_project_id = sql.Column(sql.String(64), index=True)
     _resource_option_mapper = orm.relationship(
         'UserOption',
         single_parent=True,
@@ -105,7 +105,10 @@ class User(sql.ModelBase, sql.DictBase):
     def password(self):
         """Return the current password."""
         if self.password_ref:
-            return self.password_ref.password
+            if self.password_ref.password_hash is not None:
+                return self.password_ref.password_hash
+            else:
+                return self.password_ref.password
         return None
 
     @property
@@ -125,7 +128,7 @@ class User(sql.ModelBase, sql.DictBase):
     @property
     def password_is_expired(self):
         """Return whether password is expired or not."""
-        if self.password_expires_at:
+        if self.password_expires_at and not self._password_expiry_exempt():
             return datetime.datetime.utcnow() >= self.password_expires_at
         return False
 
@@ -143,32 +146,40 @@ class User(sql.ModelBase, sql.DictBase):
             if not ref.expires_at or ref.expires_at > now:
                 ref.expires_at = now
         new_password_ref = Password()
-        new_password_ref.password = value
+
+        hashed_passwd = None
+        hashed_compat = None
+        if value is not None:
+            # NOTE(notmorgan): hash the passwords, never directly bind the
+            # "value" in the unhashed form to hashed_passwd or hashed_compat
+            # to ensure the unhashed password cannot end up in the db. If an
+            # unhashed password ends up in the DB, it cannot be used for auth,
+            # it is however incorrect and could leak user credentials (due to
+            # users doing insecure things such as sharing passwords across
+            # different systems) to unauthorized parties.
+            hashed_passwd = password_hashing.hash_password(value)
+
+            # TODO(notmorgan): Remove this compat code in Q release.
+            if CONF.identity.rolling_upgrade_password_hash_compat:
+                hashed_compat = password_hashing.hash_password_compat(value)
+
+        new_password_ref.password_hash = hashed_passwd
+        new_password_ref.password = hashed_compat
         new_password_ref.created_at = now
         new_password_ref.expires_at = self._get_password_expires_at(now)
         self.local_user.passwords.append(new_password_ref)
 
-    def _get_password_expires_at(self, created_at):
-        expires_days = CONF.security_compliance.password_expires_days
-        # NOTE(notmorgan): This option is deprecated and subject to removal
-        # in a future release.
-        ignore_list = CONF.security_compliance.password_expires_ignore_user_ids
-        if ignore_list:
-            versionutils.deprecated(
-                what='[security_compliance]\password_expires_ignore_user_ids',
-                as_of=versionutils.deprecated.OCATA,
-                remove_in=+1,
-                in_favor_of=('Using the `ignore_password_expiry` value set to '
-                             '`True` in the `user["options"]` dictionary on '
-                             'User creation or update (via API call).'))
+    def _password_expiry_exempt(self):
         # Get the IGNORE_PASSWORD_EXPIRY_OPT value from the user's
         # option_mapper.
-
-        ignore_pw_expiry = getattr(
+        return getattr(
             self.get_resource_option(iro.IGNORE_PASSWORD_EXPIRY_OPT.option_id),
             'option_value',
             False)
-        if (self.id not in ignore_list) and not ignore_pw_expiry:
+
+    def _get_password_expires_at(self, created_at):
+        expires_days = CONF.security_compliance.password_expires_days
+        if not self._password_expiry_exempt():
             if expires_days:
                 expired_date = (created_at +
                                 datetime.timedelta(days=expires_days))
@@ -255,7 +266,7 @@ class User(sql.ModelBase, sql.DictBase):
         return user_obj
 
 
-class LocalUser(sql.ModelBase, sql.DictBase):
+class LocalUser(sql.ModelBase, sql.ModelDictMixin):
     __tablename__ = 'local_user'
     attributes = ['id', 'user_id', 'domain_id', 'name']
     id = sql.Column(sql.Integer, primary_key=True)
@@ -267,7 +278,7 @@ class LocalUser(sql.ModelBase, sql.DictBase):
                                  cascade='all,delete-orphan',
                                  lazy='subquery',
                                  backref='local_user',
-                                 order_by='Password.created_at')
+                                 order_by='Password.created_at_int')
     failed_auth_count = sql.Column(sql.Integer, nullable=True)
     failed_auth_at = sql.Column(sql.DateTime, nullable=True)
     __table_args__ = (
@@ -279,21 +290,53 @@ class LocalUser(sql.ModelBase, sql.DictBase):
     )
 
 
-class Password(sql.ModelBase, sql.DictBase):
+class Password(sql.ModelBase, sql.ModelDictMixin):
     __tablename__ = 'password'
-    attributes = ['id', 'local_user_id', 'password', 'created_at',
-                  'expires_at']
+    attributes = ['id', 'local_user_id', 'password', 'password_hash',
+                  'created_at', 'expires_at']
     id = sql.Column(sql.Integer, primary_key=True)
     local_user_id = sql.Column(sql.Integer, sql.ForeignKey('local_user.id',
                                ondelete='CASCADE'))
+    # TODO(notmorgan): in the Q release the "password" field can be dropped as
+    # long as data migration exists to move the hashes over to the
+    # password_hash column if no value is in the password_hash column.
     password = sql.Column(sql.String(128), nullable=True)
+    password_hash = sql.Column(sql.String(255), nullable=True)
+
+    # TODO(lbragstad): Once Rocky opens for development, the _created_at and
+    # _expires_at attributes/columns can be removed from the schema. The
+    # migration ensures all passwords are converted from datetime objects to
+    # big integers. The old datetime columns and their corresponding attributes
+    # in the model are no longer required.
     # created_at default set here to safe guard in case it gets missed
-    created_at = sql.Column(sql.DateTime, nullable=False,
-                            default=datetime.datetime.utcnow)
-    expires_at = sql.Column(sql.DateTime, nullable=True)
+    _created_at = sql.Column('created_at', sql.DateTime, nullable=False,
+                             default=datetime.datetime.utcnow)
+    _expires_at = sql.Column('expires_at', sql.DateTime, nullable=True)
+    # set the default to 0, a 0 indicates it is unset.
+    created_at_int = sql.Column(sql.DateTimeInt(), nullable=False,
+                                default=datetime.datetime.utcnow)
+    expires_at_int = sql.Column(sql.DateTimeInt(), nullable=True)
     self_service = sql.Column(sql.Boolean, default=False, nullable=False,
                               server_default='0')
 
+    @hybrid_property
+    def created_at(self):
+        return self.created_at_int or self._created_at
+
+    @created_at.setter
+    def created_at(self, value):
+        self._created_at = value
+        self.created_at_int = value
+
+    @hybrid_property
+    def expires_at(self):
+        return self.expires_at_int or self._expires_at
+
+    @expires_at.setter
+    def expires_at(self, value):
+        self._expires_at = value
+        self.expires_at_int = value
+
 
 class FederatedUser(sql.ModelBase, sql.ModelDictMixin):
     __tablename__ = 'federated_user'
@@ -330,7 +373,7 @@ class NonLocalUser(sql.ModelBase, sql.ModelDictMixin):
             onupdate='CASCADE', ondelete='CASCADE'),)
 
 
-class Group(sql.ModelBase, sql.DictBase):
+class Group(sql.ModelBase, sql.ModelDictMixinWithExtras):
     __tablename__ = 'group'
     attributes = ['id', 'name', 'domain_id', 'description']
     id = sql.Column(sql.String(64), primary_key=True)
@@ -343,7 +386,7 @@ class Group(sql.ModelBase, sql.DictBase):
     __table_args__ = (sql.UniqueConstraint('domain_id', 'name'),)
 
 
-class UserGroupMembership(sql.ModelBase, sql.DictBase):
+class UserGroupMembership(sql.ModelBase, sql.ModelDictMixin):
     """Group membership join table."""
 
     __tablename__ = 'user_group_membership'
