@@ -15,6 +15,7 @@
 """Main entry point into the Identity service."""
 
 import functools
+import itertools
 import operator
 import os
 import threading
@@ -33,7 +34,7 @@ from keystone.common import manager
 from keystone.common.validation import validators
 import keystone.conf
 from keystone import exception
-from keystone.i18n import _, _LW
+from keystone.i18n import _
 from keystone.identity.mapping_backends import mapping
 from keystone import notifications
 from oslo_utils import timeutils
@@ -109,7 +110,7 @@ class DomainConfigs(dict):
             domain_ref = resource_api.get_domain_by_name(domain_name)
         except exception.DomainNotFound:
             LOG.warning(
-                _LW('Invalid domain name (%s) found in config file name'),
+                ('Invalid domain name (%s) found in config file name'),
                 domain_name)
             return
 
@@ -146,7 +147,7 @@ class DomainConfigs(dict):
         """
         conf_dir = CONF.identity.domain_config_dir
         if not os.path.exists(conf_dir):
-            LOG.warning(_LW('Unable to locate domain config directory: %s'),
+            LOG.warning('Unable to locate domain config directory: %s',
                         conf_dir)
             return
 
@@ -266,8 +267,7 @@ class DomainConfigs(dict):
         for group in specific_config:
             for option in specific_config[group]:
                 domain_config['cfg'].set_override(
-                    option, specific_config[group][option],
-                    group, enforce_type=True)
+                    option, specific_config[group][option], group)
 
         domain_config['cfg_overrides'] = specific_config
         domain_config['driver'] = self._load_driver(domain_config)
@@ -438,8 +438,7 @@ def exception_translated(exception_type):
 @notifications.listener
 @dependency.provider('identity_api')
 @dependency.requires('assignment_api', 'credential_api', 'id_mapping_api',
-                     'resource_api', 'revoke_api', 'shadow_users_api',
-                     'federation_api')
+                     'resource_api', 'shadow_users_api', 'federation_api')
 class Manager(manager.Manager):
     """Default pivot point for the Identity backend.
 
@@ -491,7 +490,11 @@ class Manager(manager.Manager):
             notifications.ACTIONS.internal, notifications.DOMAIN_DELETED,
             self._domain_deleted
         )
-        self.event_callbacks = {}
+        self.event_callbacks = {
+            notifications.ACTIONS.deleted: {
+                'project': [self._unset_default_project],
+            },
+        }
 
     def _domain_deleted(self, service, resource_type, operation,
                         payload):
@@ -530,8 +533,31 @@ class Manager(manager.Manager):
                            'cleanup.'),
                           {'userid': user['id'], 'domainid': domain_id})
 
-    # Domain ID normalization methods
+    def _unset_default_project(self, service, resource_type, operation,
+                               payload):
+        """Callback, clears user default_project_id after project deletion.
 
+        Notifications are used to unset a user's default project because
+        there is no foreign key to the project. Projects can be in a non-SQL
+        backend, making FKs impossible.
+
+        """
+        project_id = payload['resource_info']
+        drivers = itertools.chain(
+            self.domain_configs.values(), [{'driver': self.driver}]
+        )
+        for d in drivers:
+            try:
+                d['driver'].unset_default_project_id(project_id)
+            except exception.Forbidden:
+                # NOTE(lbragstad): If the driver throws a Forbidden, it's
+                # because the driver doesn't support writes. This is the case
+                # with the in-tree LDAP implementation since it is read-only.
+                # This also ensures consistency for out-of-tree backends that
+                # might be read-only.
+                pass
+
+    # Domain ID normalization methods
     def _set_domain_id_and_mapping(self, ref, domain_id, driver,
                                    entity_type):
         """Patch the domain_id/public_id into the resulting entity(ies).
@@ -733,10 +759,10 @@ class Manager(manager.Manager):
         if (not driver.is_domain_aware() and driver == self.driver and
             domain_id != CONF.identity.default_domain_id and
                 domain_id is not None):
-                    LOG.warning(_LW('Found multiple domains being mapped to a '
-                                    'driver that does not support that (e.g. '
-                                    'LDAP) - Domain ID: %(domain)s, '
-                                    'Default Driver: %(driver)s'),
+                    LOG.warning('Found multiple domains being mapped to a '
+                                'driver that does not support that (e.g. '
+                                'LDAP) - Domain ID: %(domain)s, '
+                                'Default Driver: %(driver)s',
                                 {'domain': domain_id,
                                  'driver': (driver == self.driver)})
                     raise exception.DomainNotFound(domain_id=domain_id)
