@@ -30,11 +30,12 @@ from pycadf import eventfactory
 from pycadf import reason
 from pycadf import resource
 
-from keystone import exception
-from keystone.i18n import _, _LE
 from keystone.common import dependency
 from keystone.common import utils
 import keystone.conf
+from keystone import exception
+from keystone.i18n import _
+
 
 _CATALOG_HELPER_OBJ = None
 
@@ -315,7 +316,7 @@ def _get_notifier():
             _notifier = oslo_messaging.Notifier(transport,
                                                 "identity.%s" % host)
         except Exception:
-            LOG.exception(_LE("Failed to construct notifier"))
+            LOG.exception("Failed to construct notifier")
             _notifier = False
 
     return _notifier
@@ -420,8 +421,8 @@ def _send_notification(operation, resource_type, resource_id, actor_dict=None,
             try:
                 notifier.info(context, event_type, payload)
             except Exception:
-                LOG.exception(_LE(
-                    'Failed to send %(res_id)s %(event_type)s notification'),
+                LOG.exception(
+                    'Failed to send %(res_id)s %(event_type)s notification',
                     {'res_id': resource_id, 'event_type': event_type})
 
 
@@ -717,8 +718,8 @@ def _send_audit_notification(action, initiator, outcome, target,
         except Exception:
             # diaper defense: any exception that occurs while emitting the
             # notification should not interfere with the API request
-            LOG.exception(_LE(
-                'Failed to send %(action)s %(event_type)s notification'),
+            LOG.exception(
+                'Failed to send %(action)s %(event_type)s notification',
                 {'action': action, 'event_type': event_type})
 
 
