@@ -21,7 +21,6 @@ import hashlib
 import json
 import ldap
 import os
-import re
 import shutil
 import socket
 import sys
@@ -124,7 +123,7 @@ class EggLoader(loadwsgi.EggLoader):
         return egg_ep
 
 
-# NOTE(dstanek): class paths were remove from the keystone-paste.ini in
+# NOTE(dstanek): class paths were removed from the keystone-paste.ini in
 # favor of using entry points. This caused tests to slow to a crawl
 # since we reload the application object for each RESTful test. This
 # monkey-patching adds caching to paste deploy's egg lookup.
@@ -598,12 +597,6 @@ class TestCase(BaseTestCase):
             group='catalog',
             driver='sql',
             template_file=dirs.tests('default_catalog.templates'))
-        self.config_fixture.config(
-            group='kvs',
-            backends=[
-                ('keystone.tests.unit.test_kvs.'
-                 'KVSBackendForcedKeyMangleFixture'),
-                'keystone.tests.unit.test_kvs.KVSBackendFixture'])
         self.config_fixture.config(
             group='signing', certfile=signing_certfile,
             keyfile=signing_keyfile,
@@ -626,6 +619,14 @@ class TestCase(BaseTestCase):
                 'keystone.notifications=INFO',
                 'keystone.identity.backends.ldap.common=INFO',
             ])
+        # NOTE(notmorgan): Set password rounds low here to ensure speedy
+        # tests. This is explicitly set because the tests here are not testing
+        # the integrity of the password hashing, just that the correct form
+        # of hashing has been used. Note that 4 is the lowest for bcrypt
+        # allowed in the `[identity] password_hash_rounds` setting
+        self.config_fixture.config(group='identity', password_hash_rounds=4)
+        self.config_fixture.config(crypt_strength=1000)
+
         self.useFixture(
             ksfixtures.KeyRepository(
                 self.config_fixture,
@@ -707,48 +708,27 @@ class TestCase(BaseTestCase):
             hasattr(self, 'assignment_api') and
                 hasattr(self, 'resource_api')):
             for domain in fixtures.DOMAINS:
-                try:
-                    rv = self.resource_api.create_domain(domain['id'], domain)
-                except exception.Conflict:
-                    rv = self.resource_api.get_domain(domain['id'])
-                except exception.NotImplemented:
-                    rv = domain
+                rv = self.resource_api.create_domain(domain['id'], domain)
                 attrname = 'domain_%s' % domain['id']
                 setattr(self, attrname, rv)
                 fixtures_to_cleanup.append(attrname)
 
             for tenant in fixtures.TENANTS:
                 tenant_attr_name = 'tenant_%s' % tenant['name'].lower()
-                if hasattr(self, tenant_attr_name):
-                    try:
-                        # This will clear out any roles on the project as well
-                        self.resource_api.delete_project(tenant['id'])
-                    except exception.ProjectNotFound:
-                        pass
                 rv = self.resource_api.create_project(
                     tenant['id'], tenant)
-
                 setattr(self, tenant_attr_name, rv)
                 fixtures_to_cleanup.append(tenant_attr_name)
 
             for role in fixtures.ROLES:
-                try:
-                    rv = self.role_api.create_role(role['id'], role)
-                except exception.Conflict:
-                    rv = self.role_api.get_role(role['id'])
-                attrname = 'role_%s' % role['id']
+                rv = self.role_api.create_role(role['id'], role)
+                attrname = 'role_%s' % role['name']
                 setattr(self, attrname, rv)
                 fixtures_to_cleanup.append(attrname)
 
             for user in fixtures.USERS:
                 user_copy = user.copy()
                 tenants = user_copy.pop('tenants')
-                try:
-                    existing_user = getattr(self, 'user_%s' % user['id'], None)
-                    if existing_user is not None:
-                        self.identity_api.delete_user(existing_user['id'])
-                except exception.UserNotFound:
-                    pass
 
                 # For users, the manager layer will generate the ID
                 user_copy = self.identity_api.create_user(user_copy)
@@ -758,15 +738,12 @@ class TestCase(BaseTestCase):
                 user_copy['password'] = user['password']
 
                 for tenant_id in tenants:
-                    try:
-                        self.assignment_api.add_user_to_project(
-                            tenant_id, user_copy['id'])
-                    except exception.Conflict:
-                        pass
+                    self.assignment_api.add_user_to_project(
+                        tenant_id, user_copy['id'])
                 # Use the ID from the fixture as the attribute name, so
                 # that our tests can easily reference each user dict, while
                 # the ID in the dict will be the real public ID.
-                attrname = 'user_%s' % user['id']
+                attrname = 'user_%s' % user['name']
                 setattr(self, attrname, user_copy)
                 fixtures_to_cleanup.append(attrname)
 
@@ -775,11 +752,8 @@ class TestCase(BaseTestCase):
                 user = role_assignment['user']
                 tenant_id = role_assignment['tenant_id']
                 user_id = getattr(self, 'user_%s' % user)['id']
-                try:
-                    self.assignment_api.add_role_to_user_and_project(
-                        user_id, tenant_id, role_id)
-                except exception.Conflict:
-                    pass
+                self.assignment_api.add_role_to_user_and_project(
+                    user_id, tenant_id, role_id)
 
             self.addCleanup(self.cleanup_instance(*fixtures_to_cleanup))
 
@@ -822,32 +796,6 @@ class TestCase(BaseTestCase):
     def assertNotEmpty(self, l):
         self.assertGreater(len(l), 0)
 
-    def assertRaisesRegexp(self, expected_exception, expected_regexp,
-                           callable_obj, *args, **kwargs):
-        """Assert that the message in a raised exception matches a regexp."""
-        try:
-            callable_obj(*args, **kwargs)
-        except expected_exception as exc_value:
-            if isinstance(expected_regexp, six.string_types):
-                expected_regexp = re.compile(expected_regexp)
-
-            if isinstance(exc_value.args[0], six.text_type):
-                if not expected_regexp.search(six.text_type(exc_value)):
-                    raise self.failureException(
-                        '"%s" does not match "%s"' %
-                        (expected_regexp.pattern, six.text_type(exc_value)))
-            else:
-                if not expected_regexp.search(str(exc_value)):
-                    raise self.failureException(
-                        '"%s" does not match "%s"' %
-                        (expected_regexp.pattern, str(exc_value)))
-        else:
-            if hasattr(expected_exception, '__name__'):
-                excName = expected_exception.__name__
-            else:
-                excName = str(expected_exception)
-            raise self.failureException("%s not raised" % excName)
-
     def assertUserDictEqual(self, expected, observed, message=''):
         """Assert that a user dict is equal to another user dict.
 
