@@ -59,21 +59,6 @@ class IdentityTestCaseStaticAdminToken(test_v3.RestfulTestCase):
         self.get('/users', token=CONF.admin_token,
                  expected_status=exception.Unauthorized.code)
 
-    def test_create_user_with_admin_token_and_no_domain(self):
-        """Call ``POST /users`` with admin token but no domain id.
-
-        It should not be possible to use the admin token to create a user
-        while not explicitly passing the domain in the request body.
-
-        """
-        # Passing a valid domain id to new_user_ref() since domain_id is
-        # not an optional parameter.
-        ref = unit.new_user_ref(domain_id=self.domain_id)
-        # Delete the domain id before sending the request.
-        del ref['domain_id']
-        self.post('/users', body={'user': ref}, token=CONF.admin_token,
-                  expected_status=http_client.BAD_REQUEST)
-
 
 class IdentityTestCase(test_v3.RestfulTestCase):
     """Test users and groups."""
@@ -838,9 +823,6 @@ class ChangePasswordTestCase(test_v3.RestfulTestCase):
 
 class UserSelfServiceChangingPasswordsTestCase(ChangePasswordTestCase):
 
-    def setUp(self):
-        super(UserSelfServiceChangingPasswordsTestCase, self).setUp()
-
     def _create_user_with_expired_password(self):
         expire_days = CONF.security_compliance.password_expires_days + 1
         time = (
