@@ -60,12 +60,12 @@ class Routers(wsgi.RoutersBase):
         self._add_resource(
             mapper, controller,
             path=self._construct_url('ca'),
-            get_action='get_ca_certificate',
+            get_head_action='get_ca_certificate',
             rel=build_resource_relation(resource_name='ca_certificate'))
         self._add_resource(
             mapper, controller,
             path=self._construct_url('certificates'),
-            get_action='list_certificates',
+            get_head_action='list_certificates',
             rel=build_resource_relation(resource_name='certificates'))
 
 
@@ -82,7 +82,8 @@ class SimpleCert(controller.V3Controller):
         # NOTE(jamielennox): We construct the webob Response ourselves here so
         # that we don't pass through the JSON encoding process.
         headers = [('Content-Type', 'application/x-pem-file')]
-        return webob.Response(body=body, headerlist=headers, status="200 OK")
+        return webob.Response(body=body, headerlist=headers,
+                              status="200 OK", charset='utf-8')
 
     def get_ca_certificate(self, context):
         return self._get_certificate(CONF.signing.ca_certs)
