@@ -15,14 +15,13 @@
 import datetime
 import sys
 
-from keystone.common import utils
 from keystoneclient.common import cms
-from oslo_log import log
 from oslo_serialization import jsonutils
 import six
 
 from keystone.common import controller
 from keystone.common import dependency
+from keystone.common import utils
 from keystone.common import wsgi
 import keystone.conf
 from keystone import exception
@@ -32,7 +31,6 @@ from keystone.token.providers import common
 
 
 CONF = keystone.conf.CONF
-LOG = log.getLogger(__name__)
 
 
 def authentication_method_generator(request, auth):
@@ -67,9 +65,8 @@ class ExternalAuthNotApplicable(Exception):
     pass
 
 
-@dependency.requires('assignment_api', 'catalog_api', 'identity_api',
-                     'resource_api', 'role_api', 'token_provider_api',
-                     'trust_api')
+@dependency.requires('catalog_api', 'identity_api', 'resource_api',
+                     'token_provider_api', 'trust_api')
 class Auth(controller.V2Controller):
 
     @controller.v2_deprecated
@@ -519,7 +516,7 @@ class ExternalAuthenticationMethod(BaseAuthenticationMethod):
         return (user_ref, tenant_id, expiry, bind, audit_id)
 
 
-@dependency.requires('catalog_api', 'resource_api', 'assignment_api',
+@dependency.requires('catalog_api', 'resource_api',
                      'trust_api', 'identity_api')
 class V2TokenDataHelper(object):
     """Create V2 token data."""
