@@ -13,6 +13,7 @@
 # under the License.
 
 from oslo_serialization import jsonutils
+from six.moves import http_client
 import webob
 
 from keystone.common import extension
@@ -26,14 +27,11 @@ MEDIA_TYPE_JSON = 'application/vnd.openstack.identity-%s+json'
 _VERSIONS = []
 
 # NOTE(blk-u): latest_app will be set by keystone.version.service.loadapp(). It
-# gets set to the application that was just loaded. In the case of keystone-all
-# loadapp() gets called twice, once for the public app and once for the admin
-# app. In the case of httpd/keystone, loadapp() gets called once for the public
-# app if this is the public instance or loadapp() gets called for the admin app
-# if it's the admin instance.
-# This is used to fetch the /v3 JSON Home response. The /v3 JSON Home response
-# is the same whether it's the admin or public service so either admin or
-# public works.
+# gets set to the application that was just loaded. loadapp() gets called once
+# for the public app if this is the public instance or loadapp() gets called
+# for the admin app if it's the admin instance. This is used to fetch the /v3
+# JSON Home response. The /v3 JSON Home response is the same whether it's the
+# admin or public service so either admin or public works.
 latest_app = None
 
 
@@ -59,10 +57,10 @@ class Extensions(wsgi.Application):
     def extensions(self):
         return None
 
-    def get_extensions_info(self, context):
+    def get_extensions_info(self, request):
         return {'extensions': {'values': list(self.extensions.values())}}
 
-    def get_extension_info(self, context, extension_alias):
+    def get_extension_info(self, request, extension_alias):
         try:
             return {'extension': self.extensions[extension_alias]}
         except KeyError:
@@ -90,10 +88,10 @@ class MimeTypes(object):
     JSON_HOME = 'application/json-home'
 
 
-def v3_mime_type_best_match(context):
+def v3_mime_type_best_match(request):
 
     # accept_header is a WebOb MIMEAccept object so supports best_match.
-    accept_header = context['accept_header']
+    accept_header = request.accept
 
     if not accept_header:
         return MimeTypes.JSON
@@ -111,7 +109,7 @@ class Version(wsgi.Application):
         super(Version, self).__init__()
 
     def _get_identity_url(self, context, version):
-        """Returns a URL to keystone's own endpoint."""
+        """Return a URL to keystone's own endpoint."""
         url = self.base_url(context, self.endpoint_url_type)
         return '%s/%s/' % (url, version)
 
@@ -121,8 +119,8 @@ class Version(wsgi.Application):
         if 'v2.0' in _VERSIONS:
             versions['v2.0'] = {
                 'id': 'v2.0',
-                'status': 'stable',
-                'updated': '2014-04-17T00:00:00Z',
+                'status': 'deprecated',
+                'updated': '2016-08-04T00:00:00Z',
                 'links': [
                     {
                         'rel': 'self',
@@ -130,7 +128,7 @@ class Version(wsgi.Application):
                     }, {
                         'rel': 'describedby',
                         'type': 'text/html',
-                        'href': 'http://docs.openstack.org/'
+                        'href': 'https://docs.openstack.org/'
                     }
                 ],
                 'media-types': [
@@ -143,9 +141,9 @@ class Version(wsgi.Application):
 
         if 'v3' in _VERSIONS:
             versions['v3'] = {
-                'id': 'v3.6',
+                'id': 'v3.8',
                 'status': 'stable',
-                'updated': '2016-04-04T00:00:00Z',
+                'updated': '2017-02-22T00:00:00Z',
                 'links': [
                     {
                         'rel': 'self',
@@ -162,24 +160,27 @@ class Version(wsgi.Application):
 
         return versions
 
-    def get_versions(self, context):
+    def get_versions(self, request):
 
-        req_mime_type = v3_mime_type_best_match(context)
+        req_mime_type = v3_mime_type_best_match(request)
         if req_mime_type == MimeTypes.JSON_HOME:
             v3_json_home = request_v3_json_home('/v3')
             return wsgi.render_response(
                 body=v3_json_home,
                 headers=(('Content-Type', MimeTypes.JSON_HOME),))
 
-        versions = self._get_versions_list(context)
-        return wsgi.render_response(status=(300, 'Multiple Choices'), body={
-            'versions': {
-                'values': list(versions.values())
-            }
-        })
+        versions = self._get_versions_list(request.context_dict)
+        return wsgi.render_response(
+            status=(http_client.MULTIPLE_CHOICES,
+                    http_client.responses[http_client.MULTIPLE_CHOICES]),
+            body={
+                'versions': {
+                    'values': list(versions.values())
+                }
+            })
 
-    def get_version_v2(self, context):
-        versions = self._get_versions_list(context)
+    def get_version_v2(self, request):
+        versions = self._get_versions_list(request.context_dict)
         if 'v2.0' in _VERSIONS:
             return wsgi.render_response(body={
                 'version': versions['v2.0']
@@ -198,10 +199,10 @@ class Version(wsgi.Application):
             'resources': dict(all_resources())
         }
 
-    def get_version_v3(self, context):
-        versions = self._get_versions_list(context)
+    def get_version_v3(self, request):
+        versions = self._get_versions_list(request.context_dict)
         if 'v3' in _VERSIONS:
-            req_mime_type = v3_mime_type_best_match(context)
+            req_mime_type = v3_mime_type_best_match(request)
 
             if req_mime_type == MimeTypes.JSON_HOME:
                 return wsgi.render_response(
